<?php

class MnglAppController
{
  function MnglAppController()
  {
    add_filter('the_content', array( $this, 'page_route' ), 1);
    add_action('wp_enqueue_scripts', array($this, 'load_scripts'), 1); 
    register_activation_hook(MNGL_PATH."/mingle.php", array( $this, 'install' ));
    
    // Used to process standalone requests
    add_action('init', array($this,'parse_standalone_request'));
    add_action('init', array($this,'load_language'));
    
    // Process User registration
    add_filter('pre_user_first_name', array($this, 'add_user_first_name'));
    add_filter('pre_user_last_name', array($this, 'add_user_last_name'));
  }
  
  /********* INSTALL PLUGIN ***********/
  function install()
  {
    global $wpdb;
    $db_version = 3; // this is the version of the database we're moving to
    $old_db_version = get_option('mngl_db_version');

    $friends_table           = $wpdb->prefix . "mngl_friends";
    $friend_requests_table   = $wpdb->prefix . "mngl_friend_requests";
    $board_posts_table       = $wpdb->prefix . "mngl_board_posts";
    $board_comments_table    = $wpdb->prefix . "mngl_board_comments";

    $charset_collate = '';
    if( $wpdb->has_cap( 'collation' ) )
    {
      if( !empty($wpdb->charset) )
        $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
      if( !empty($wpdb->collate) )
        $charset_collate .= " COLLATE $wpdb->collate";
    }

    if($db_version != $old_db_version)
    {
      require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

      /* Create/Upgrade Friends Table */
      $sql = "CREATE TABLE {$friends_table} (
                id int(11) NOT NULL auto_increment,
                user_id int(11) NOT NULL,
                friend_id int(11) NOT NULL,
                status varchar(255) DEFAULT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY user_id (user_id),
                KEY friend_id (friend_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
      
      /* Create/Upgrade Friend Requests Table */
      $sql = "CREATE TABLE {$friend_requests_table} (
                id int(11) NOT NULL auto_increment,
                user_id int(11) NOT NULL,
                friend_id int(11) NOT NULL,
                friend_record_a_id int(11) NOT NULL,
                friend_record_b_id int(11) NOT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY user_id (user_id),
                KEY friend_id (friend_id),
                KEY friend_record_a_id (friend_record_a_id),
                KEY friend_record_b_id (friend_record_b_id)
              ) {$charset_collate};";
    
      dbDelta($sql);

      /* Create/Upgrade Board Posts Table */
      $sql = "CREATE TABLE {$board_posts_table} (
                id int(11) NOT NULL auto_increment,
                owner_id int(11) NOT NULL,
                author_id int(11) NOT NULL,
                message text DEFAULT NULL,
                type varchar(255) DEFAULT 'post',
                source varchar(255) DEFAULT NULL,
                visibility varchar(255) DEFAULT 'public',
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY owner_id (owner_id),
                KEY author_id (author_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
      
      /* Create/Upgrade Board Comments Table */
      $sql = "CREATE TABLE {$board_comments_table} (
                id int(11) NOT NULL auto_increment,
                author_id int(11) NOT NULL,
                message text DEFAULT NULL,
                board_post_id int(11) NOT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY author_id (author_id),
                KEY board_post_id (board_post_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
    }

    /***** SAVE DB VERSION *****/
    delete_option('mngl_db_version');
    add_option('mngl_db_version',$db_version);
  }
  
  // Routes for wordpress pages -- we're just replacing content here folks.
  function page_route($content)
  {
    global $post, $mngl_options, $profiles_controller, $friends_controller;

    switch( $post->ID )
    {  
      case $mngl_options->activity_page_id:
        $profiles_controller->activity();
        return '';
      case $mngl_options->profile_page_id:
        $profiles_controller->profile();
        return '';
      case $mngl_options->directory_page_id:
        $profiles_controller->directory($this->get_param('mdp'));
        return '';
      case $mngl_options->profile_edit_page_id:
        $profiles_controller->edit();
        return '';
      case $mngl_options->friends_page_id:
        $friends_controller->list_friends($this->get_param('mdp'));
        return '';
      case $mngl_options->friend_requests_page_id:
        $friends_controller->list_friend_requests();
        return '';
      case $mngl_options->login_page_id:
        $this->display_login_form($this->get_param('redirect_to'));
        return '';
      case $mngl_options->signup_page_id:
        $this->display_signup_form();
        return '';
    }
      
    return $content;
  }  

  function load_scripts()
  {
    global $mngl_blogurl, $post, $mngl_options;

    wp_enqueue_style( 'mingle',  MNGL_CSS_URL . '/mingle.css' );
    wp_enqueue_script( 'mingle', MNGL_SCRIPT_URL . '&controller=js&action=mingle', array('jquery') );
  }
  
  function mingle_js()
  {
    header('Content-type: application/javascript');
    require_once( MNGL_JS_PATH . '/mingle.js.php' );
  }

  // The tight way to process standalone requests dogg...
  function parse_standalone_request()
  {
    $plugin     = $this->get_param('plugin');
    $action     = $this->get_param('action');
    $controller = $this->get_param('controller');
    
    if( is_user_logged_in() and 
        !empty($plugin) and $plugin == 'mingle' and 
        !empty($controller) and !empty($action) )
    {
      $this->standalone_route($controller, $action);
      exit;
    }
  }
  
  // Routes for standalone / ajax requests
  function standalone_route($controller, $action)
  {
    global $friends_controller, $boards_controller, $profiles_controller;
    
    if($controller=='friends')
    {
      if($action=='friend_request')
        $friends_controller->friend_request($this->get_param('user_id'), $this->get_param('friend_id'));
      if($action=='delete_friend')
        $friends_controller->delete_friend($this->get_param('user_id'), $this->get_param('friend_id'));
      else if($action=='accept_friend')
        $friends_controller->accept_friend($this->get_param('request_id'));
      else if($action=='ignore_friend')
        $friends_controller->ignore_friend($this->get_param('request_id'));
    }
    else if($controller=='boards')
    {
      if($action=='post')
        $boards_controller->post($this->get_param('owner_id'), $this->get_param('author_id'), $this->get_param('message'));
      else if($action=='comment')
        $boards_controller->comment($this->get_param('board_post_id'), $this->get_param('author_id'), $this->get_param('message'));
      else if($action=='delete_post')
        $boards_controller->delete_post($this->get_param('board_post_id'));
      else if($action=='delete_comment')
        $boards_controller->delete_comment($this->get_param('board_comment_id'));
    }
    else if($controller=='activity')
    {
      if($action=='post')
        $boards_controller->post($this->get_param('owner_id'), $this->get_param('author_id'), $this->get_param('message'),true);
      else if($action=='comment')
        $boards_controller->comment($this->get_param('board_post_id'), $this->get_param('author_id'), $this->get_param('message'),true);
      else if($action=='delete_post')
        $boards_controller->delete_post($this->get_param('board_post_id'),true);
      else if($action=='delete_comment')
        $boards_controller->delete_comment($this->get_param('board_comment_id'),true);
    }
    else if($controller=='profile')
    {  
      if($action=='delete_avatar')
        $profiles_controller->delete_avatar($this->get_param('user_id'));
    }
    else if($controller=='js')
    {
      if($action=='mingle')
        $this->mingle_js();
    }
    
  }
  
  function load_language()
  {
    $path_from_plugins_folder = preg_replace('#^'.ABSPATH.'#', '', MNGL_PATH) . '/i18n/';
    
    load_plugin_textdomain( 'mingle', $path_from_plugins_folder );
  }
  
  // Utility function to grab the parameter whether it's a get or post
  function get_param($param)
  {
    return (isset($_POST[$param])?$_POST[$param]:$_GET[$param]);
  }
  
  function get_param_delimiter_char($link)
  { 
    return ((preg_match("#\?#",$link))?'&':'?');
  }
  
  function display_login_form($redirect_to)
  {
    global $mngl_options, $mngl_blogurl;
    
    $redirect_to = ((!empty($redirect_to))?$redirect_to:get_permalink($mngl_options->activity_page_id));

    if(!empty($mngl_options->signup_page_id) and $mngl_options->signup_page_id > 0)
      $signup_url = get_permalink($mngl_options->signup_page_id);
    else
      $signup_url = $mngl_blogurl . '/wp-login.php?action=register';
    
    if(is_user_logged_in()) 
      require( MNGL_VIEWS_PATH . '/shared/already_logged_in.php' );
    else
      require( MNGL_VIEWS_PATH . '/shared/login_form.php' );
  }
  
  function display_signup_form()
  {
    global $mngl_options, $mngl_blogurl;
    
    if(is_user_logged_in()) 
      require( MNGL_VIEWS_PATH . '/shared/already_logged_in.php' );
    else
      require( MNGL_VIEWS_PATH . '/shared/signup_form.php' );
  }
  
  function add_user_first_name($first_name)
  {
    if(empty($first_name) and !empty($_POST['mngl_user_first-name']))
      $first_name = $_POST['mngl_user_first-name'];
      
    return $first_name;
  }
  
  function add_user_last_name($last_name)
  {
    if(empty($last_name) and !empty($_POST['mngl_user_last-name']))
      $last_name = $_POST['mngl_user_last-name'];
      
    return $last_name;
  }
}
?>
