<?php

class MnglBoardsController
{
  function MnglBoardsController()
  {
    add_filter('mngl-activity-types', array( $this, 'add_activity_types' ));
  }
  
  function add_activity_types($activity_types)
  {
    $activity_types['board_posts'] = array( 'name'         => 'Board Posts',
                                            'message'      => __('%1$s posted to %2$s\'s board', 'mingle') . '|$owner->first_name, $author_profile_link',
                                            'icon'         => MNGL_URL . '/images/board_post.png' );
    $activity_types['board_comments'] = array( 'name'         => 'Board Comments',
                                               'message'      => __('%1$s commented on %2$s\'s post', 'mingle') . '|$owner->first_name, $author_profile_link',
                                               'icon'         => MNGL_URL . '/images/board_comment.png' );
    return $activity_types;
  }

  function display($user_id, $page=1, $page_size=25)
  {
    global $mngl_options, $mngl_friend, $mngl_user, $app_helper, $mngl_board_post, $mngl_board_comment, $current_user;
    
    $page_start_index = (($page-1)*$page_size);
    
    $owner_id  = $user_id;
    $author_id = $mngl_user->id;
    
    $messages = "'" . implode("','",array_keys($mngl_options->activity_types)) . "'";
    $board_posts = $mngl_board_post->get_all_by_user_id( $user_id, true, " AND (type='post' or (type='activity' and source IN ({$messages})))", 'created_at DESC', "{$page_start_index},{$page_size}" );
    
    require_once MNGL_VIEWS_PATH . "/mngl-boards/display.php";
  }
  
  function activity_display($user_id, $page=1, $page_size=50)
  {
    global $mngl_friend, $mngl_user, $app_helper, $mngl_board_post, $mngl_board_comment, $current_user;
    
    $page_start_index = (($page-1)*$page_size);
    
    $owner_id  = $user_id;
    $author_id = $mngl_user->id;
    $public = true;
    
    $board_posts = $mngl_board_post->get_all_public_by_user_id( $user_id, true, '', 'created_at DESC', "{$page_start_index},{$page_size}" );
    
    require_once MNGL_VIEWS_PATH . "/mngl-boards/display.php";
  }

  function post($owner_id, $author_id, $message, $public=false)
  {
    global $mngl_friend, $mngl_user, $mngl_board_post;
    
    if( is_user_logged_in() and
        ( ($owner_id==$author_id) or
          $mngl_friend->is_friend($owner_id, $author_id) ) )
      $mngl_board_post->create($owner_id, $author_id, strip_tags(stripslashes($message)));
      
    if( is_user_logged_in() and ($owner_id==$author_id) )
      $mngl_user->update_status(strip_tags(stripslashes($message)));
    
    if( is_user_logged_in() and ($owner_id!=$author_id) )
      $mngl_board_post->add_activity_by_id( $author_id, $owner_id, 'board_posts' );
    
    if($public)
      $this->activity_display($owner_id);
    else
      $this->display($owner_id);
  }
  
  function comment($board_post_id, $author_id, $message, $public=false)
  {
    global $mngl_friend, $mngl_board_comment, $mngl_board_post;
    
    $board_post = $mngl_board_post->get_one($board_post_id);
    
    if( is_user_logged_in() and
        ( ($board_post->owner_id == $author_id) or
          $mngl_friend->is_friend($board_post->owner_id, $author_id) ) )
      $mngl_board_comment->create($board_post_id, $author_id, strip_tags(stripslashes($message)));

    if( is_user_logged_in() and 
        ( $board_post->owner_id != $author_id ) and
        ( $board_post->author_id != $author_id ) )
      $mngl_board_post->add_activity_by_id( $author_id, $board_post->owner_id, 'board_comments' );
    
    if($public)
      $this->activity_display($board_post->owner_id);
    else
      $this->display($board_post->owner_id);
  }
  
  function delete_post($board_post_id, $public=false)
  {
    global $mngl_board_post, $mngl_user;
    
    $board_post = $mngl_board_post->get_one($board_post_id);

    if( $mngl_user->is_logged_in_and_current_user($board_post->owner_id) or
        $mngl_user->is_logged_in_and_current_user($board_post->author_id) or
        $mngl_user->is_logged_in_and_an_admin())
      $mngl_board_post->delete($board_post_id);

    if($public)
      $this->activity_display($board_post->owner_id);
    else
      $this->display($board_post->owner_id);
  }
  
  function delete_comment($board_comment_id, $public=false)
  {
    global $mngl_board_comment, $mngl_board_post, $mngl_user;
    
    $board_comment = $mngl_board_comment->get_one($board_comment_id);
    $board_post = $mngl_board_post->get_one($board_comment->board_post_id);

    if( $mngl_user->is_logged_in_and_current_user($board_post->owner_id) or
        $mngl_user->is_logged_in_and_current_user($board_comment->author_id) or
        $mngl_user->is_logged_in_and_an_admin())
      $mngl_board_comment->delete($board_comment_id);

    if($public)
      $this->activity_display($board_post->owner_id);
    else
      $this->display($board_post->owner_id);
  }
  
  function display_comment_form( $author_id, $board_post_id, $public=false )
  {
    $author = MnglUser::get_stored_profile_by_id($author_id);
    
    $avatar_url = $author->get_avatar_url();
    $avatar_dimensions = $author->get_avatar_dimensions(36);
    
    require( MNGL_VIEWS_PATH . "/mngl-boards/comment_form.php" );
  }
}
?>
