<?php

class MnglBoardPost
{
  var $table_name;
  
  function MnglBoardPost()
  {
    global $wpdb;
    $this->table_name = "{$wpdb->prefix}mngl_board_posts";
  }

  function create( $owner_id, $author_id, $message='', $type='post', $source='', $visibility='public' )
  {
    if( $type == 'post' and empty($message) )
      return false;
      
    global $wpdb;
    $query_str = "INSERT INTO {$this->table_name} " . 
                   '(owner_id,'.
                    'author_id,'.
                    'message,'.
                    'type,'.
                    'source,'.
                    'visibility,'.
                    'created_at) ' .
                    'VALUES (%d,%d,%s,%s,%s,%s,NOW())';
    
    $query = $wpdb->prepare( $query_str,
                             $owner_id,
                             $author_id,
                             $message,
                             $type,
                             $source,
                             $visibility );
                             
    $query_results = $wpdb->query($query);

    if($query_results)
    {
      if($type=='post')
        MnglNotification::board_posted($wpdb->insert_id);
      
      return $wpdb->insert_id;
    }
    else
      return false;
  }
  
  function update( $id, $message )
  {
    global $wpdb;
    $query_str = "UPDATE {$this->table_name} " . 
                    'SET message=%s ' .
                    'WHERE id=%d';
    
    $query = $wpdb->prepare( $query_str,
                             $message,
                             $id );

    return $wpdb->query($query);
  }
  
  function delete( $id )
  {
    global $wpdb, $mngl_board_comment;
    
    $mngl_board_comment->delete_all_by_board_post_id( $id );

    $query_str = "DELETE FROM {$this->table_name} WHERE id=%d";
    
    $query = $wpdb->prepare( $query_str,
                             $id );
                             
    return $wpdb->query($query);
  }
  
  function get_one( $id )
  {
    global $wpdb;
    
    $query_str = "SELECT * FROM {$this->table_name} WHERE id=%d";
    $query = $wpdb->prepare( $query_str, $id);

    return $wpdb->get_row($query);
  }
  
  function get_all( $where='', $order_by='', $limit='' )
  {
    global $wpdb;
    
    $where    = ((empty($where))?'':" WHERE {$where}");
    $order_by = ((empty($order_by))?'':" ORDER BY {$order_by}");
    $limit    = ((empty($limit))?'':" LIMIT {$limit}");
    
    $query_str = "SELECT * FROM {$this->table_name}{$where}{$order_by}{$limit}";
    $query = $wpdb->prepare( $query_str );

    return $wpdb->get_results($query);
  }
  
  function get_all_public_by_user_id( $owner_id, $include_comments=false, $additional_where='', $order_by='', $limit='' )
  {
    global $mngl_friend, $wpdb;
    
    $friend_ids = $mngl_friend->get_all_ids_by_user_id( $owner_id, "status = 'verified'" );
    
    $where .= "visibility='public' AND (";
    $where .= "author_id={$owner_id}";

    foreach ($friend_ids as $key => $friend_id)
      $where .= " OR author_id={$friend_id}";
      
    $where .= "){$additional_where}";

    $order_by = ((empty($order_by))?'':" ORDER BY {$order_by}");
    $limit    = ((empty($limit))?'':" LIMIT {$limit}");
    
    $query_str   = "SELECT * FROM {$this->table_name} WHERE {$where}{$order_by}{$limit}";
    $query       = $wpdb->prepare( $query_str, $owner_id );

    $board_posts = $wpdb->get_results($query);

    if($include_comments)
    {
      global $mngl_board_comment;
      foreach ($board_posts as $board_post)
        $board_post->comments = $mngl_board_comment->get_all_by_board_post_id( $board_post->id, '', 'created_at DESC' );
    }
    
    return $board_posts;
  }
  
  function get_all_by_user_id( $owner_id, $include_comments=false, $where='', $order_by='', $limit='' )
  {
    global $wpdb;

    $order_by = ((empty($order_by))?'':" ORDER BY {$order_by}");
    $limit    = ((empty($limit))?'':" LIMIT {$limit}");
    
    $query_str   = "SELECT * FROM {$this->table_name} WHERE owner_id=%d{$where}{$order_by}{$limit}";
    $query       = $wpdb->prepare( $query_str, $owner_id );
    $board_posts = $wpdb->get_results($query);

    if($include_comments)
    {
      global $mngl_board_comment;
      foreach ($board_posts as $board_post)
        $board_post->comments = $mngl_board_comment->get_all_by_board_post_id( $board_post->id, '', 'created_at DESC' );
    }
    
    return $board_posts;
  }
  
  function add_activity_by_id( $owner_id, $author_id, $message_type, $vars='', $visibility='personal' )
  {
    $owner  = MnglUser::get_stored_profile_by_id($owner_id);
    $author = MnglUser::get_stored_profile_by_id($author_id);
    
    MnglBoardPost::add_activity( $owner, $author, $message_type, $visibility );
  }
  
  function add_activity_by_screenname( $owner_screenname, $author_screenname, $message_type, $vars='', $visibility='personal' )
  {
    $owner  = MnglUser::get_stored_profile_by_screenname($owner_screenname);
    $author = MnglUser::get_stored_profile_by_screenname($author_screenname);
    
    MnglBoardPost::add_activity( $owner, $author, $message_type, $visibility );
  }
  
  function add_activity( $owner, $author, $message_type, $vars='', $visibility='personal' )
  { 
    $vars_str = '';

    if(!empty($vars) and is_array($vars))
      $vars_str = serialize($vars);

    $this->create( $owner->id, $author->id, $vars_str, 'activity', $message_type, $visibility );
  }
}
?>
